@@ -22,11 +22,77 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <errno.h>
 
 #include "config.h"
 #include "seahorse-gpgmex.h"
 #include <glib.h>
 
+/* -----------------------------------------------------------------------------
+ * DATA
+ */
+
+gpgme_data_t 
+gpgmex_data_new ()
+{
+    gpgme_error_t gerr;
+    gpgme_data_t data;
+    
+    gerr = gpgme_data_new (&data);
+    if (!GPG_IS_OK (gerr)) {
+        if (gpgme_err_code_to_errno (gerr) == ENOMEM || 
+            gpgme_err_code (gerr) == GPG_ERR_ENOMEM) {
+                
+            g_error ("%s: failed to allocate gpgme_data_t", G_STRLOC);
+                
+        } else {
+            /* The only reason this should fail is above */
+            g_assert_not_reached ();
+            
+            /* Just in case */
+            abort ();
+        }
+    }
+    
+    return data;
+}
+
+gpgme_data_t
+gpgmex_data_new_from_mem (const char *buffer, size_t size, gboolean copy)
+{
+    gpgme_data_t data;
+    gpgme_error_t gerr;
+    
+    gerr = gpgme_data_new_from_mem (&data, buffer, size, copy ? 1 : 0);
+    if (!GPG_IS_OK (gerr)) {
+        if (gpgme_err_code_to_errno (gerr) == ENOMEM || 
+            gpgme_err_code (gerr) == GPG_ERR_ENOMEM) {
+                
+            g_error ("%s: failed to allocate gpgme_data_t", G_STRLOC);
+                
+        } else {
+            /* The only reason this should fail is above */
+            g_assert_not_reached ();
+            
+            /* Just in case */
+            abort ();
+        }
+    }
+    
+    return data;
+}
+
+void
+gpgmex_data_release (gpgme_data_t data)
+{
+    if (data)
+        gpgme_data_release (data);
+}
+
+/* -----------------------------------------------------------------------------
+ * KEYS
+ */
+ 
 /* Our special keylist mode flag */
 #define SEAHORSE_KEYLIST_MODE    0x04000000
 
@@ -319,6 +385,34 @@ gpgmex_key_is_gpgme (gpgme_key_t key)
     return !(key->keylist_mode & SEAHORSE_KEYLIST_MODE);
 }
 
+gpgmex_photo_id_t 
+gpgmex_photo_id_alloc (guint uid)
+{
+    gpgmex_photo_id_t photoid = g_new0 (struct _gpgmex_photo_id, 1);
+    photoid->uid = uid;
+    return photoid;
+}
+
+void        
+gpgmex_photo_id_free (gpgmex_photo_id_t photoid)
+{
+    if (photoid) {
+        if (photoid->photo)
+            g_object_unref (photoid->photo);
+        g_free (photoid);
+    }
+}
+
+void 
+gpgmex_photo_id_free_all (gpgmex_photo_id_t photoid)
+{
+    while (photoid) {
+        gpgmex_photo_id_t next = photoid->next;
+        gpgmex_photo_id_free (photoid);
+        photoid = next;
+    }
+}
+
 /* -----------------------------------------------------------------------------
  * OTHER MISC FUNCTIONS
  */
