@@ -18,14 +18,14 @@
  * 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
+#include <config.h>
 #include <gnome.h>
 
 #include "config.h"
 #include "seahorse-prefs.h"
 #include "seahorse-util.h"
 #include "seahorse-check-button-control.h"
-#include "seahorse-default-key-control.h"
+#include "seahorse-combo-keys.h"
 #include "seahorse-keyserver-control.h"
 #include "seahorse-server-source.h"
 #include "seahorse-gconf.h"
