@@ -19,11 +19,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
 #include <config.h>
+#include <gnome.h>
 #include <locale.h>
 
-#include "config.h"
 #include "seahorse-context.h"
 #include "seahorse-prefs.h"
 #include "seahorse-gtkstock.h"
@@ -67,6 +66,10 @@ main (int argc, char **argv)
     SeahorseOperation *op;
     GOptionContext *octx = NULL;
 
+    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
+
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
 
